@@ -3,6 +3,10 @@ import time
 import logging
 import uuid
 
+from figgy.data.dao.audit import AuditDao
+from figgy.data.dao.replication import ReplicationDao
+
+from figcli.commands.command_context import CommandContext
 from figcli.commands.config_context import ConfigContext
 from figcli.commands.config_factory import ConfigFactory
 from figcli.commands.help_context import HelpContext
@@ -10,16 +14,19 @@ from figcli.commands.help_factory import HelpFactory
 from figcli.commands.iam_context import IAMContext
 from figcli.commands.iam_factory import IAMFactory
 from figcli.commands.factory import Factory
+from figcli.commands.ui_factory import UIFactory
 from figcli.models.defaults.defaults import CLIDefaults
 from figgy.models.run_env import RunEnv
 from figcli.commands.figgy_context import FiggyContext
-from figcli.svcs.kms import KmsSvc
+from figcli.svcs.kms import KmsService
 from figcli.svcs.config import ConfigService
 from figcli.svcs.cache_manager import CacheManager
 from figcli.svcs.auth.provider.provider_factory import SessionProviderFactory
 from figcli.svcs.auth.provider.session_provider import SessionProvider
 from figcli.svcs.auth.session_manager import SessionManager
 from figgy.data.dao.config import ConfigDao
+
+from figcli.ui.models.global_environment import GlobalEnvironment
 from figcli.utils.utils import Utils
 from figcli.config import *
 from figgy.data.dao.ssm import SsmDao
@@ -28,6 +35,7 @@ from concurrent.futures import ThreadPoolExecutor, thread, as_completed
 
 from figcli.views.rbac_limited_config import RBACLimitedConfigView
 from threading import Lock
+
 logger = logging.getLogger(__name__)
 
 
@@ -53,12 +61,14 @@ class CommandFactory(Factory):
         self._config_svc = None
         self._cache_mgr = None
         self._rbac_config_view = None
+        self._audit = None
+        self._repl = None
         self.__env_lock = Lock()
         self.__mgr_lock = Lock()
 
     def __session_provider(self) -> SessionProvider:
         if not self._session_provider:
-            self._session_provider = SessionProviderFactory(self._cli_defaults).instance()
+            self._session_provider = SessionProviderFactory(self._cli_defaults, self._context).instance()
 
         return self._session_provider
 
@@ -73,6 +83,9 @@ class CommandFactory(Factory):
 
         return self._session_mgr
 
+    def __build_env(self) -> GlobalEnvironment:
+        return GlobalEnvironment(role=self._context.selected_role, region=self._cli_defaults.region)
+
     def __env_session(self) -> boto3.session.Session:
         """
         Lazy load an ENV session object for the ENV selected in the FiggyContext
@@ -81,11 +94,23 @@ class CommandFactory(Factory):
         with self.__env_lock:
             if not self._env_session:
                 self._env_session = self.__session_manager().get_session(
-                    self._context.selected_role,
+                    self.__build_env(),
                     prompt=False)
 
         return self._env_session
 
+    def __audit(self) -> AuditDao:
+        if not self._audit:
+            self._audit = AuditDao(self.__env_session().resource('dynamodb'))
+
+        return self._audit
+
+    def __repl(self) -> ReplicationDao:
+        if not self._repl:
+            self._repl = ReplicationDao(self.__env_session().resource('dynamodb'))
+
+        return self._repl
+
     def __ssm(self) -> SsmDao:
         """
         Returns an SSMDao initialized with a session for the selected ENV based on FiggyContext
@@ -95,12 +120,12 @@ class CommandFactory(Factory):
 
         return self._ssm
 
-    def __kms(self) -> KmsSvc:
+    def __kms(self) -> KmsService:
         """
         Returns a hydrated KMS Service object based on these selected ENV
         """
         if not self._kms:
-            self._kms: KmsSvc = KmsSvc(self.__env_session().client('kms'))
+            self._kms: KmsService = KmsService(self.__env_session().client('kms'), self.__ssm())
 
         return self._kms
 
@@ -145,15 +170,15 @@ class CommandFactory(Factory):
     def __cache_mgr(self) -> CacheManager:
         """Builds a cache manager service for the specified resource."""
         if not self._cache_mgr:
-            self._cache_mgr: CacheManager = CacheManager(Utils.get_first(self._context.resource))
+            self._cache_mgr: CacheManager = CacheManager(self._context.resource)
 
         return self._cache_mgr
 
     def __config_service(self) -> ConfigService:
         """Returns a hydrated ConfigService."""
         if not self._config_svc:
-            self._config_svc = ConfigService(self.__config(), self.__ssm(),
-                                             self.__cache_mgr(), self._context.run_env)
+            self._config_svc = ConfigService(self.__config(), self.__ssm(), self.__repl(),
+                                             self.__cache_mgr(), self.__kms(), self._context.run_env)
 
         return self._config_svc
 
@@ -169,8 +194,8 @@ class CommandFactory(Factory):
         Bootstraps sessions (blocking) before we do threaded lookups that require these sessions.
         """
         self.__session_manager().get_session(
-                self._context.selected_role,
-                prompt=False)
+            self.__build_env(),
+            prompt=False)
 
     def instance(self):
         """
@@ -178,13 +203,13 @@ class CommandFactory(Factory):
         """
         factory: Factory = None
         start = time.time()
-
         if self._context.command in config_commands and self._context.resource == config:
-            self.__init_sessions()
+            if self._context.command != ui:
+                self.__init_sessions()
+
             context = ConfigContext(self._context.run_env, self._context.role, self._context.args, config,
                                     defaults=self._cli_defaults)
 
-
             futures = set()
             # Multiple threads to init resources saves 500 - 1000 MS
             with ThreadPoolExecutor(max_workers=5) as pool:
@@ -197,7 +222,7 @@ class CommandFactory(Factory):
 
             factory = ConfigFactory(self._context.command, context, self.__ssm(), self.__config_service(),
                                     self.__config(), self.__kms(), self.__s3_resource(), self._context.colors_enabled,
-                                    self.__rbac_config_view(), self.__session_manager())
+                                    self.__rbac_config_view(), self.__audit(), self.__repl(), self.__session_manager())
 
         elif self._context.command in iam_commands and self._context.resource == iam:
             self.__init_sessions()
@@ -205,11 +230,17 @@ class CommandFactory(Factory):
                                  defaults=self._cli_defaults)
             factory = IAMFactory(self._context.command, context, self.__env_session(),
                                  all_sessions=self.__all_sessions())
+
         elif self._context.find_matching_optional_arguments(help_commands) or self._context.resource in help_commands:
             optional_args = self._context.find_matching_optional_arguments(help_commands)
             context = HelpContext(self._context.resource, self._context.command, optional_args, self._context.run_env,
                                   defaults=self._cli_defaults, role=self._context.role)
-            factory = HelpFactory(self._context.command, context)
+            factory = HelpFactory(self._context.command, context, self._context)
+
+        elif self._context.command in ui_commands or self._context.resource == ui:
+            context = CommandContext(self._context.run_env, self._context.command, defaults=self._cli_defaults)
+            factory = UIFactory(self._context.command, context, self.__session_manager(), self._context)
+
         else:
             if self._context.command is None or self._context.resource:
                 self._utils.error_exit(f"Proper {CLI_NAME} syntax is `{CLI_NAME} <resource> <command> --options`. "
@@ -217,7 +248,7 @@ class CommandFactory(Factory):
                                        f"not supplied.")
             else:
                 self._utils.error_exit(
-                    f"Command: {self._utils.get_first(self._context.command)} was not found in this version of figgy.")
+                    f"Command: {self._context.command.name} was not found in this version of figgy.")
 
         logger.info(f"Init completed in {time.time() - start} seconds.")
         return factory.instance()
