@@ -2,6 +2,8 @@ import requests
 from abc import ABC
 import re
 from typing import List
+
+from figcli.commands.figgy_context import FiggyContext
 from figcli.commands.help_context import HelpContext
 from figcli.commands.types.help import HelpCommand
 from figcli.config import *
@@ -29,21 +31,22 @@ class Login(HelpCommand, ABC):
     This improves figgy performance throughout the day.
     """
 
-    def __init__(self, help_context: HelpContext, figgy_setup: FiggySetup):
+    def __init__(self, help_context: HelpContext, figgy_setup: FiggySetup, figgy_context: FiggyContext):
         super().__init__(login, Utils.not_windows(), help_context)
         self._setup = figgy_setup
         self._defaults: CLIDefaults = figgy_setup.get_defaults()
+        self._figgy_context = figgy_context
         self._utils = Utils(self._defaults.colors_enabled)
         self._aws_cfg = AWSConfig(color=self.c)
 
-        self.example = f"\n\n{self.c.fg_bl}{CLI_NAME} {Utils.get_first(login)} \n" \
+        self.example = f"\n\n{self.c.fg_bl}{CLI_NAME} {login.name} \n" \
                        f"{self.c.rs}{self.c.fg_yl}  --or--{self.c.rs}\n" \
-                       f"{self.c.fg_bl}{CLI_NAME} {Utils.get_first(login)} {Utils.get_first(sandbox)}{self.c.rs}"
+                       f"{self.c.fg_bl}{CLI_NAME} {login.name} {sandbox.name}{self.c.rs}"
 
     def login(self):
         self._utils.validate(self._defaults.provider.name in Provider.names(),
                              f"You cannot login until you've configured Figgy. Please run `{CLI_NAME}` --configure")
-        provider = SessionProviderFactory(self._defaults).instance()
+        provider = SessionProviderFactory(self._defaults, self._figgy_context).instance()
         assumable_roles: List[AssumableRole] = provider.get_assumable_roles()
         print(f"{self.c.fg_bl}Found {len(assumable_roles)} possible logins. Logging in...{self.c.rs}")
 
@@ -92,7 +95,7 @@ class Login(HelpCommand, ABC):
         config_mgr = ConfigManager.figgy()
         config_mgr.set(Config.Section.Bastion.PROFILE, FIGGY_SANDBOX_PROFILE)
         defaults = self._setup.configure_extras(defaults)
-        defaults = self._setup.configure_roles(current_defaults=defaults, role=Role(role), run_env=run_env)
+        defaults = self._setup.configure_roles(current_defaults=defaults, role=Role(role=role), run_env=run_env)
         defaults = self._setup.configure_figgy_defaults(defaults)
         self._setup.save_defaults(defaults)
 
