@@ -1,10 +1,12 @@
-from typing import List
+from typing import List, Optional
 import boto3
 import botocore
 
+from figcli.commands.figgy_context import FiggyContext
 from figcli.models.assumable_role import AssumableRole
 from figcli.models.defaults.defaults import CLIDefaults
 from figcli.svcs.auth.provider.session_provider import SessionProvider
+from figcli.ui.models.global_environment import GlobalEnvironment
 from figcli.utils.utils import Utils
 
 class ProfileSessionProvider(SessionProvider):
@@ -17,15 +19,15 @@ class ProfileSessionProvider(SessionProvider):
     This provider always returns a session from the targeted profile.
     """
 
-    def __init__(self, defaults: CLIDefaults):
-        super().__init__(defaults)
+    def __init__(self, defaults: CLIDefaults, context: FiggyContext):
+        super().__init__(defaults, context)
 
-    def get_session(self, assumable_role: AssumableRole, prompt: bool, exit_on_fail=True) -> boto3.Session:
+    def get_session(self, env: GlobalEnvironment, prompt: bool, exit_on_fail=True, mfa: Optional[str] = None) -> boto3.Session:
 
         try:
-            return boto3.Session(profile_name=assumable_role.profile)
+            return boto3.Session(profile_name=env.role.profile)
         except botocore.exceptions.ProfileNotFound:
-            Utils.stc_error_exit(f"The provided profile override of {assumable_role.profile} is invalid. Are you sure "
+            Utils.stc_error_exit(f"The provided profile override of {env.role.profile} is invalid. Are you sure "
                                  f"this profile is set in your ~/.aws/credentials and ~/.aws/config files?")
 
     def cleanup_session_cache(self):
